# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConsumerGroupsGroupResult',
    'GetHistoryDeliveryJobsJobResult',
    'GetHistoryDeliveryJobsJobJobStatusResult',
    'GetInstancesInstanceResult',
    'GetInstancesInstanceAllowedListResult',
    'GetInstancesInstanceAllowedListInternetListResult',
    'GetInstancesInstanceAllowedListVpcListResult',
    'GetInstancesInstanceUpgradeServiceDetailInfoResult',
    'GetSaslAclsAclResult',
    'GetSaslUsersUserResult',
    'GetTopicsTopicResult',
    'GetTrailsActiontrailResult',
    'GetTrailsDeprecatedActiontrailResult',
    'GetTrailsDeprecatedTrailResult',
    'GetTrailsTrailResult',
]

@pulumi.output_type
class GetConsumerGroupsGroupResult(dict):
    def __init__(__self__, *,
                 consumer_id: str,
                 id: str,
                 instance_id: str,
                 remark: str,
                 tags: Optional[Mapping[str, str]] = None):
        """
        :param str consumer_id: The name of the consumer group.
        :param str id: The ID of the consumer group, It is formatted to `<instance_id>:<consumer_id>`.
        :param str instance_id: ID of the ALIKAFKA Instance that owns the consumer groups.
        :param str remark: The remark of the consumer group.
        :param Mapping[str, str] tags: A mapping of tags to assign to the consumer group.
        """
        pulumi.set(__self__, "consumer_id", consumer_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "remark", remark)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> str:
        """
        The name of the consumer group.
        """
        return pulumi.get(self, "consumer_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the consumer group, It is formatted to `<instance_id>:<consumer_id>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        ID of the ALIKAFKA Instance that owns the consumer groups.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def remark(self) -> str:
        """
        The remark of the consumer group.
        """
        return pulumi.get(self, "remark")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        A mapping of tags to assign to the consumer group.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetHistoryDeliveryJobsJobResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 end_time: str,
                 history_delivery_job_id: str,
                 home_region: str,
                 id: str,
                 job_statuses: Sequence['outputs.GetHistoryDeliveryJobsJobJobStatusResult'],
                 start_time: str,
                 status: int,
                 trail_name: str,
                 updated_time: str):
        """
        :param str create_time: The time when the task was created.
        :param str end_time: The time when the task ended.
        :param str home_region: The home region of the trail.
        :param str id: The ID of the History Delivery Job.
        :param Sequence['GetHistoryDeliveryJobsJobJobStatusArgs'] job_statuses: Detail status of delivery job.
        :param str start_time: The time when the task started.
        :param int status: The status of the task. Valid values: `0`, `1`, `2`, `3`. `0`: The task is initializing. `1`: The task is delivering historical events. `2`: The delivery of historical events is complete. `3`: The task fails.
        :param str trail_name: The name of the trail.
        :param str updated_time: The time when the task was updated.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "history_delivery_job_id", history_delivery_job_id)
        pulumi.set(__self__, "home_region", home_region)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "job_statuses", job_statuses)
        pulumi.set(__self__, "start_time", start_time)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "trail_name", trail_name)
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time when the task was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> str:
        """
        The time when the task ended.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="historyDeliveryJobId")
    def history_delivery_job_id(self) -> str:
        return pulumi.get(self, "history_delivery_job_id")

    @property
    @pulumi.getter(name="homeRegion")
    def home_region(self) -> str:
        """
        The home region of the trail.
        """
        return pulumi.get(self, "home_region")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the History Delivery Job.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="jobStatuses")
    def job_statuses(self) -> Sequence['outputs.GetHistoryDeliveryJobsJobJobStatusResult']:
        """
        Detail status of delivery job.
        """
        return pulumi.get(self, "job_statuses")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> str:
        """
        The time when the task started.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the task. Valid values: `0`, `1`, `2`, `3`. `0`: The task is initializing. `1`: The task is delivering historical events. `2`: The delivery of historical events is complete. `3`: The task fails.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trailName")
    def trail_name(self) -> str:
        """
        The name of the trail.
        """
        return pulumi.get(self, "trail_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> str:
        """
        The time when the task was updated.
        """
        return pulumi.get(self, "updated_time")


@pulumi.output_type
class GetHistoryDeliveryJobsJobJobStatusResult(dict):
    def __init__(__self__, *,
                 region: str,
                 status: int):
        """
        :param str region: The region of the delivery job.
        :param int status: The status of the task. Valid values: `0`, `1`, `2`, `3`. `0`: The task is initializing. `1`: The task is delivering historical events. `2`: The delivery of historical events is complete. `3`: The task fails.
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region of the delivery job.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the task. Valid values: `0`, `1`, `2`, `3`. `0`: The task is initializing. `1`: The task is delivering historical events. `2`: The delivery of historical events is complete. `3`: The task fails.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 allowed_lists: Sequence['outputs.GetInstancesInstanceAllowedListResult'],
                 config: str,
                 create_time: str,
                 deploy_type: int,
                 disk_size: int,
                 disk_type: int,
                 domain_endpoint: str,
                 eip_max: int,
                 end_point: str,
                 expired_time: int,
                 id: str,
                 io_max: int,
                 msg_retain: int,
                 name: str,
                 paid_type: str,
                 partition_num: int,
                 sasl_domain_endpoint: str,
                 security_group: str,
                 service_status: int,
                 service_version: str,
                 spec_type: str,
                 ssl_domain_endpoint: str,
                 ssl_end_point: str,
                 topic_quota: int,
                 upgrade_service_detail_infos: Sequence['outputs.GetInstancesInstanceUpgradeServiceDetailInfoResult'],
                 vpc_id: str,
                 vswitch_id: str,
                 zone_id: str,
                 tags: Optional[Mapping[str, str]] = None):
        """
        :param Sequence['GetInstancesInstanceAllowedListArgs'] allowed_lists: The allowed list of the instance.
        :param str config: The config the instance.
        :param str create_time: The create time of the instance.
        :param int deploy_type: The deployed type of the instance.
        :param int disk_size: The disk size of the instance.
        :param int disk_type: The disk type of the instance. 0: efficient cloud disk , 1: SSD.
        :param str domain_endpoint: The domain point of the instance.
        :param int eip_max: The peak bandwidth of the instance.
        :param str end_point: The endPoint to access the instance.
        :param int expired_time: The expired time  of the instance.
        :param str id: ID of the instance.
        :param int io_max: The peak value of io of the instance.
        :param int msg_retain: The msg retain of the instance.
        :param str name: Name of the instance.
        :param str paid_type: The paid type of the instance.
        :param int partition_num: (Available in 1.194.0+) The number of partitions.
        :param str sasl_domain_endpoint: The SASL domain point of the instance.
        :param str security_group: The security group of the instance.
        :param int service_status: The current status of the instance. -1: unknown status, 0: wait deploy, 1: initializing, 2: preparing, 3 starting, 5: in service, 7: wait upgrade, 8: upgrading, 10: released, 15: freeze, 101: deploy error, 102: upgrade error.
        :param str service_version: The kafka openSource version of the instance.
        :param str spec_type: The spec type of the instance.
        :param str ssl_domain_endpoint: The SSL domain point of the instance.
        :param str ssl_end_point: The SSL end point of the instance.
        :param int topic_quota: The max num of topic can be create of the instance.
        :param Sequence['GetInstancesInstanceUpgradeServiceDetailInfoArgs'] upgrade_service_detail_infos: The UpgradeServiceDetailInfo List.
        :param str vpc_id: The ID of attaching VPC to instance.
        :param str vswitch_id: The ID of attaching vswitch to instance.
        :param str zone_id: The ID of attaching zone to instance.
        :param Mapping[str, str] tags: A mapping of tags to assign to the instance.
        """
        pulumi.set(__self__, "allowed_lists", allowed_lists)
        pulumi.set(__self__, "config", config)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "deploy_type", deploy_type)
        pulumi.set(__self__, "disk_size", disk_size)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "domain_endpoint", domain_endpoint)
        pulumi.set(__self__, "eip_max", eip_max)
        pulumi.set(__self__, "end_point", end_point)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "io_max", io_max)
        pulumi.set(__self__, "msg_retain", msg_retain)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "paid_type", paid_type)
        pulumi.set(__self__, "partition_num", partition_num)
        pulumi.set(__self__, "sasl_domain_endpoint", sasl_domain_endpoint)
        pulumi.set(__self__, "security_group", security_group)
        pulumi.set(__self__, "service_status", service_status)
        pulumi.set(__self__, "service_version", service_version)
        pulumi.set(__self__, "spec_type", spec_type)
        pulumi.set(__self__, "ssl_domain_endpoint", ssl_domain_endpoint)
        pulumi.set(__self__, "ssl_end_point", ssl_end_point)
        pulumi.set(__self__, "topic_quota", topic_quota)
        pulumi.set(__self__, "upgrade_service_detail_infos", upgrade_service_detail_infos)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="allowedLists")
    def allowed_lists(self) -> Sequence['outputs.GetInstancesInstanceAllowedListResult']:
        """
        The allowed list of the instance.
        """
        return pulumi.get(self, "allowed_lists")

    @property
    @pulumi.getter
    def config(self) -> str:
        """
        The config the instance.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The create time of the instance.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> int:
        """
        The deployed type of the instance.
        """
        return pulumi.get(self, "deploy_type")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> int:
        """
        The disk size of the instance.
        """
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> int:
        """
        The disk type of the instance. 0: efficient cloud disk , 1: SSD.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="domainEndpoint")
    def domain_endpoint(self) -> str:
        """
        The domain point of the instance.
        """
        return pulumi.get(self, "domain_endpoint")

    @property
    @pulumi.getter(name="eipMax")
    def eip_max(self) -> int:
        """
        The peak bandwidth of the instance.
        """
        return pulumi.get(self, "eip_max")

    @property
    @pulumi.getter(name="endPoint")
    def end_point(self) -> str:
        """
        The endPoint to access the instance.
        """
        return pulumi.get(self, "end_point")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> int:
        """
        The expired time  of the instance.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ioMax")
    def io_max(self) -> int:
        """
        The peak value of io of the instance.
        """
        return pulumi.get(self, "io_max")

    @property
    @pulumi.getter(name="msgRetain")
    def msg_retain(self) -> int:
        """
        The msg retain of the instance.
        """
        return pulumi.get(self, "msg_retain")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="paidType")
    def paid_type(self) -> str:
        """
        The paid type of the instance.
        """
        return pulumi.get(self, "paid_type")

    @property
    @pulumi.getter(name="partitionNum")
    def partition_num(self) -> int:
        """
        (Available in 1.194.0+) The number of partitions.
        """
        return pulumi.get(self, "partition_num")

    @property
    @pulumi.getter(name="saslDomainEndpoint")
    def sasl_domain_endpoint(self) -> str:
        """
        The SASL domain point of the instance.
        """
        return pulumi.get(self, "sasl_domain_endpoint")

    @property
    @pulumi.getter(name="securityGroup")
    def security_group(self) -> str:
        """
        The security group of the instance.
        """
        return pulumi.get(self, "security_group")

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> int:
        """
        The current status of the instance. -1: unknown status, 0: wait deploy, 1: initializing, 2: preparing, 3 starting, 5: in service, 7: wait upgrade, 8: upgrading, 10: released, 15: freeze, 101: deploy error, 102: upgrade error.
        """
        return pulumi.get(self, "service_status")

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> str:
        """
        The kafka openSource version of the instance.
        """
        return pulumi.get(self, "service_version")

    @property
    @pulumi.getter(name="specType")
    def spec_type(self) -> str:
        """
        The spec type of the instance.
        """
        return pulumi.get(self, "spec_type")

    @property
    @pulumi.getter(name="sslDomainEndpoint")
    def ssl_domain_endpoint(self) -> str:
        """
        The SSL domain point of the instance.
        """
        return pulumi.get(self, "ssl_domain_endpoint")

    @property
    @pulumi.getter(name="sslEndPoint")
    def ssl_end_point(self) -> str:
        """
        The SSL end point of the instance.
        """
        return pulumi.get(self, "ssl_end_point")

    @property
    @pulumi.getter(name="topicQuota")
    def topic_quota(self) -> int:
        """
        The max num of topic can be create of the instance.
        """
        return pulumi.get(self, "topic_quota")

    @property
    @pulumi.getter(name="upgradeServiceDetailInfos")
    def upgrade_service_detail_infos(self) -> Sequence['outputs.GetInstancesInstanceUpgradeServiceDetailInfoResult']:
        """
        The UpgradeServiceDetailInfo List.
        """
        return pulumi.get(self, "upgrade_service_detail_infos")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of attaching VPC to instance.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The ID of attaching vswitch to instance.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The ID of attaching zone to instance.
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        A mapping of tags to assign to the instance.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetInstancesInstanceAllowedListResult(dict):
    def __init__(__self__, *,
                 deploy_type: str,
                 internet_lists: Sequence['outputs.GetInstancesInstanceAllowedListInternetListResult'],
                 vpc_lists: Sequence['outputs.GetInstancesInstanceAllowedListVpcListResult']):
        """
        :param str deploy_type: The deployed type of the instance.
        :param Sequence['GetInstancesInstanceAllowedListInternetListArgs'] internet_lists: The internet list of the instance.
        :param Sequence['GetInstancesInstanceAllowedListVpcListArgs'] vpc_lists: The vpc list of the instance.
        """
        pulumi.set(__self__, "deploy_type", deploy_type)
        pulumi.set(__self__, "internet_lists", internet_lists)
        pulumi.set(__self__, "vpc_lists", vpc_lists)

    @property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> str:
        """
        The deployed type of the instance.
        """
        return pulumi.get(self, "deploy_type")

    @property
    @pulumi.getter(name="internetLists")
    def internet_lists(self) -> Sequence['outputs.GetInstancesInstanceAllowedListInternetListResult']:
        """
        The internet list of the instance.
        """
        return pulumi.get(self, "internet_lists")

    @property
    @pulumi.getter(name="vpcLists")
    def vpc_lists(self) -> Sequence['outputs.GetInstancesInstanceAllowedListVpcListResult']:
        """
        The vpc list of the instance.
        """
        return pulumi.get(self, "vpc_lists")


@pulumi.output_type
class GetInstancesInstanceAllowedListInternetListResult(dict):
    def __init__(__self__, *,
                 allowed_ip_lists: Sequence[str],
                 port_range: str):
        """
        :param Sequence[str] allowed_ip_lists: The allowed ip list of the internet_list.
        :param str port_range: The port range of the internet_list.
        """
        pulumi.set(__self__, "allowed_ip_lists", allowed_ip_lists)
        pulumi.set(__self__, "port_range", port_range)

    @property
    @pulumi.getter(name="allowedIpLists")
    def allowed_ip_lists(self) -> Sequence[str]:
        """
        The allowed ip list of the internet_list.
        """
        return pulumi.get(self, "allowed_ip_lists")

    @property
    @pulumi.getter(name="portRange")
    def port_range(self) -> str:
        """
        The port range of the internet_list.
        """
        return pulumi.get(self, "port_range")


@pulumi.output_type
class GetInstancesInstanceAllowedListVpcListResult(dict):
    def __init__(__self__, *,
                 allowed_ip_lists: Sequence[str],
                 port_range: str):
        """
        :param Sequence[str] allowed_ip_lists: The allowed ip list of the internet_list.
        :param str port_range: The port range of the internet_list.
        """
        pulumi.set(__self__, "allowed_ip_lists", allowed_ip_lists)
        pulumi.set(__self__, "port_range", port_range)

    @property
    @pulumi.getter(name="allowedIpLists")
    def allowed_ip_lists(self) -> Sequence[str]:
        """
        The allowed ip list of the internet_list.
        """
        return pulumi.get(self, "allowed_ip_lists")

    @property
    @pulumi.getter(name="portRange")
    def port_range(self) -> str:
        """
        The port range of the internet_list.
        """
        return pulumi.get(self, "port_range")


@pulumi.output_type
class GetInstancesInstanceUpgradeServiceDetailInfoResult(dict):
    def __init__(__self__, *,
                 current2_open_source_version: str):
        """
        :param str current2_open_source_version: The Current2OpenSourceVersion of the instance.
        """
        pulumi.set(__self__, "current2_open_source_version", current2_open_source_version)

    @property
    @pulumi.getter(name="current2OpenSourceVersion")
    def current2_open_source_version(self) -> str:
        """
        The Current2OpenSourceVersion of the instance.
        """
        return pulumi.get(self, "current2_open_source_version")


@pulumi.output_type
class GetSaslAclsAclResult(dict):
    def __init__(__self__, *,
                 acl_operation_type: str,
                 acl_resource_name: str,
                 acl_resource_pattern_type: str,
                 acl_resource_type: str,
                 host: str,
                 username: str):
        """
        :param str acl_operation_type: The operation type of the sasl acl.
        :param str acl_resource_name: Get results for the specified resource name.
        :param str acl_resource_pattern_type: The resource pattern type of the sasl acl.
        :param str acl_resource_type: Get results for the specified resource type.
        :param str host: The host of the sasl acl.
        :param str username: Get results for the specified username.
        """
        pulumi.set(__self__, "acl_operation_type", acl_operation_type)
        pulumi.set(__self__, "acl_resource_name", acl_resource_name)
        pulumi.set(__self__, "acl_resource_pattern_type", acl_resource_pattern_type)
        pulumi.set(__self__, "acl_resource_type", acl_resource_type)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="aclOperationType")
    def acl_operation_type(self) -> str:
        """
        The operation type of the sasl acl.
        """
        return pulumi.get(self, "acl_operation_type")

    @property
    @pulumi.getter(name="aclResourceName")
    def acl_resource_name(self) -> str:
        """
        Get results for the specified resource name.
        """
        return pulumi.get(self, "acl_resource_name")

    @property
    @pulumi.getter(name="aclResourcePatternType")
    def acl_resource_pattern_type(self) -> str:
        """
        The resource pattern type of the sasl acl.
        """
        return pulumi.get(self, "acl_resource_pattern_type")

    @property
    @pulumi.getter(name="aclResourceType")
    def acl_resource_type(self) -> str:
        """
        Get results for the specified resource type.
        """
        return pulumi.get(self, "acl_resource_type")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        The host of the sasl acl.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        Get results for the specified username.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetSaslUsersUserResult(dict):
    def __init__(__self__, *,
                 password: str,
                 username: str):
        """
        :param str password: The password of the user.
        :param str username: The username of the user.
        """
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def password(self) -> str:
        """
        The password of the user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetTopicsTopicResult(dict):
    def __init__(__self__, *,
                 compact_topic: bool,
                 create_time: str,
                 id: str,
                 instance_id: str,
                 local_topic: bool,
                 partition_num: int,
                 remark: str,
                 status: int,
                 status_name: str,
                 topic: str,
                 tags: Optional[Mapping[str, str]] = None):
        """
        :param bool compact_topic: whether the current topic is kafka compact topic or not.
        :param str create_time: Time of creation.
        :param str id: The ID of the topic, It is formatted to `<instance_id>:<topic>`.
        :param str instance_id: ID of the instance.
        :param bool local_topic: whether the current topic is kafka local topic or not.
        :param int partition_num: Partition number of the topic.
        :param str remark: Remark of the topic.
        :param int status: The current status code of the topic. There are three values to describe the topic status: 0 stands for the topic is in service, 1 stands for freezing and 2 stands for pause.
        :param str status_name: The status_name of the topic.
        :param str topic: A topic to filter results by the topic name.
        :param Mapping[str, str] tags: A mapping of tags to assign to the topic.
        """
        pulumi.set(__self__, "compact_topic", compact_topic)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "local_topic", local_topic)
        pulumi.set(__self__, "partition_num", partition_num)
        pulumi.set(__self__, "remark", remark)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "status_name", status_name)
        pulumi.set(__self__, "topic", topic)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="compactTopic")
    def compact_topic(self) -> bool:
        """
        whether the current topic is kafka compact topic or not.
        """
        return pulumi.get(self, "compact_topic")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Time of creation.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the topic, It is formatted to `<instance_id>:<topic>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="localTopic")
    def local_topic(self) -> bool:
        """
        whether the current topic is kafka local topic or not.
        """
        return pulumi.get(self, "local_topic")

    @property
    @pulumi.getter(name="partitionNum")
    def partition_num(self) -> int:
        """
        Partition number of the topic.
        """
        return pulumi.get(self, "partition_num")

    @property
    @pulumi.getter
    def remark(self) -> str:
        """
        Remark of the topic.
        """
        return pulumi.get(self, "remark")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The current status code of the topic. There are three values to describe the topic status: 0 stands for the topic is in service, 1 stands for freezing and 2 stands for pause.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusName")
    def status_name(self) -> str:
        """
        The status_name of the topic.
        """
        return pulumi.get(self, "status_name")

    @property
    @pulumi.getter
    def topic(self) -> str:
        """
        A topic to filter results by the topic name.
        """
        return pulumi.get(self, "topic")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        A mapping of tags to assign to the topic.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetTrailsActiontrailResult(dict):
    def __init__(__self__, *,
                 event_rw: str,
                 id: str,
                 is_organization_trail: bool,
                 oss_bucket_name: str,
                 oss_key_prefix: str,
                 oss_write_role_arn: str,
                 sls_project_arn: str,
                 sls_write_role_arn: str,
                 status: str,
                 trail_name: str,
                 trail_region: str):
        """
        :param str event_rw: Indicates whether the event is a read or a write event.
        :param str id: The id of the ActionTrail Trail. It is the same as trail name.
        :param str oss_bucket_name: The name of the specified OSS bucket.
        :param str oss_key_prefix: The prefix of the specified OSS bucket name.
        :param str sls_project_arn: The unique ARN of the Log Service project.
        :param str sls_write_role_arn: The unique ARN of the Log Service role.
        :param str status: Filter the results by status of the ActionTrail Trail. Valid values: `Disable`, `Enable`, `Fresh`.
        :param str trail_name: The name of the ActionTrail Trail.
        :param str trail_region: The regions to which the trail is applied.
        """
        pulumi.set(__self__, "event_rw", event_rw)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_organization_trail", is_organization_trail)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_key_prefix", oss_key_prefix)
        pulumi.set(__self__, "oss_write_role_arn", oss_write_role_arn)
        pulumi.set(__self__, "sls_project_arn", sls_project_arn)
        pulumi.set(__self__, "sls_write_role_arn", sls_write_role_arn)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "trail_name", trail_name)
        pulumi.set(__self__, "trail_region", trail_region)

    @property
    @pulumi.getter(name="eventRw")
    def event_rw(self) -> str:
        """
        Indicates whether the event is a read or a write event.
        """
        return pulumi.get(self, "event_rw")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the ActionTrail Trail. It is the same as trail name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOrganizationTrail")
    def is_organization_trail(self) -> bool:
        return pulumi.get(self, "is_organization_trail")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the specified OSS bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossKeyPrefix")
    def oss_key_prefix(self) -> str:
        """
        The prefix of the specified OSS bucket name.
        """
        return pulumi.get(self, "oss_key_prefix")

    @property
    @pulumi.getter(name="ossWriteRoleArn")
    def oss_write_role_arn(self) -> str:
        return pulumi.get(self, "oss_write_role_arn")

    @property
    @pulumi.getter(name="slsProjectArn")
    def sls_project_arn(self) -> str:
        """
        The unique ARN of the Log Service project.
        """
        return pulumi.get(self, "sls_project_arn")

    @property
    @pulumi.getter(name="slsWriteRoleArn")
    def sls_write_role_arn(self) -> str:
        """
        The unique ARN of the Log Service role.
        """
        return pulumi.get(self, "sls_write_role_arn")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Filter the results by status of the ActionTrail Trail. Valid values: `Disable`, `Enable`, `Fresh`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trailName")
    def trail_name(self) -> str:
        """
        The name of the ActionTrail Trail.
        """
        return pulumi.get(self, "trail_name")

    @property
    @pulumi.getter(name="trailRegion")
    def trail_region(self) -> str:
        """
        The regions to which the trail is applied.
        """
        return pulumi.get(self, "trail_region")


@pulumi.output_type
class GetTrailsDeprecatedActiontrailResult(dict):
    def __init__(__self__, *,
                 event_rw: str,
                 id: str,
                 is_organization_trail: bool,
                 oss_bucket_name: str,
                 oss_key_prefix: str,
                 oss_write_role_arn: str,
                 sls_project_arn: str,
                 sls_write_role_arn: str,
                 status: str,
                 trail_name: str,
                 trail_region: str):
        """
        :param str event_rw: Indicates whether the event is a read or a write event.
        :param str oss_bucket_name: The name of the specified OSS bucket.
        :param str oss_key_prefix: The prefix of the specified OSS bucket name.
        :param str sls_project_arn: The unique ARN of the Log Service project.
        :param str sls_write_role_arn: The unique ARN of the Log Service role.
        """
        pulumi.set(__self__, "event_rw", event_rw)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_organization_trail", is_organization_trail)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_key_prefix", oss_key_prefix)
        pulumi.set(__self__, "oss_write_role_arn", oss_write_role_arn)
        pulumi.set(__self__, "sls_project_arn", sls_project_arn)
        pulumi.set(__self__, "sls_write_role_arn", sls_write_role_arn)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "trail_name", trail_name)
        pulumi.set(__self__, "trail_region", trail_region)

    @property
    @pulumi.getter(name="eventRw")
    def event_rw(self) -> str:
        """
        Indicates whether the event is a read or a write event.
        """
        return pulumi.get(self, "event_rw")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOrganizationTrail")
    def is_organization_trail(self) -> bool:
        return pulumi.get(self, "is_organization_trail")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the specified OSS bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossKeyPrefix")
    def oss_key_prefix(self) -> str:
        """
        The prefix of the specified OSS bucket name.
        """
        return pulumi.get(self, "oss_key_prefix")

    @property
    @pulumi.getter(name="ossWriteRoleArn")
    def oss_write_role_arn(self) -> str:
        return pulumi.get(self, "oss_write_role_arn")

    @property
    @pulumi.getter(name="slsProjectArn")
    def sls_project_arn(self) -> str:
        """
        The unique ARN of the Log Service project.
        """
        return pulumi.get(self, "sls_project_arn")

    @property
    @pulumi.getter(name="slsWriteRoleArn")
    def sls_write_role_arn(self) -> str:
        """
        The unique ARN of the Log Service role.
        """
        return pulumi.get(self, "sls_write_role_arn")

    @property
    @pulumi.getter
    def status(self) -> str:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trailName")
    def trail_name(self) -> str:
        return pulumi.get(self, "trail_name")

    @property
    @pulumi.getter(name="trailRegion")
    def trail_region(self) -> str:
        return pulumi.get(self, "trail_region")


@pulumi.output_type
class GetTrailsDeprecatedTrailResult(dict):
    def __init__(__self__, *,
                 event_rw: str,
                 id: str,
                 is_organization_trail: bool,
                 oss_bucket_name: str,
                 oss_key_prefix: str,
                 oss_write_role_arn: str,
                 sls_project_arn: str,
                 sls_write_role_arn: str,
                 status: str,
                 trail_name: str,
                 trail_region: str):
        """
        :param str event_rw: Indicates whether the event is a read or a write event.
        :param str oss_bucket_name: The name of the specified OSS bucket.
        :param str oss_key_prefix: The prefix of the specified OSS bucket name.
        :param str sls_project_arn: The unique ARN of the Log Service project.
        :param str sls_write_role_arn: The unique ARN of the Log Service role.
        """
        pulumi.set(__self__, "event_rw", event_rw)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_organization_trail", is_organization_trail)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_key_prefix", oss_key_prefix)
        pulumi.set(__self__, "oss_write_role_arn", oss_write_role_arn)
        pulumi.set(__self__, "sls_project_arn", sls_project_arn)
        pulumi.set(__self__, "sls_write_role_arn", sls_write_role_arn)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "trail_name", trail_name)
        pulumi.set(__self__, "trail_region", trail_region)

    @property
    @pulumi.getter(name="eventRw")
    def event_rw(self) -> str:
        """
        Indicates whether the event is a read or a write event.
        """
        return pulumi.get(self, "event_rw")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOrganizationTrail")
    def is_organization_trail(self) -> bool:
        return pulumi.get(self, "is_organization_trail")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the specified OSS bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossKeyPrefix")
    def oss_key_prefix(self) -> str:
        """
        The prefix of the specified OSS bucket name.
        """
        return pulumi.get(self, "oss_key_prefix")

    @property
    @pulumi.getter(name="ossWriteRoleArn")
    def oss_write_role_arn(self) -> str:
        return pulumi.get(self, "oss_write_role_arn")

    @property
    @pulumi.getter(name="slsProjectArn")
    def sls_project_arn(self) -> str:
        """
        The unique ARN of the Log Service project.
        """
        return pulumi.get(self, "sls_project_arn")

    @property
    @pulumi.getter(name="slsWriteRoleArn")
    def sls_write_role_arn(self) -> str:
        """
        The unique ARN of the Log Service role.
        """
        return pulumi.get(self, "sls_write_role_arn")

    @property
    @pulumi.getter
    def status(self) -> str:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trailName")
    def trail_name(self) -> str:
        return pulumi.get(self, "trail_name")

    @property
    @pulumi.getter(name="trailRegion")
    def trail_region(self) -> str:
        return pulumi.get(self, "trail_region")


@pulumi.output_type
class GetTrailsTrailResult(dict):
    def __init__(__self__, *,
                 event_rw: str,
                 id: str,
                 is_organization_trail: bool,
                 oss_bucket_name: str,
                 oss_key_prefix: str,
                 oss_write_role_arn: str,
                 sls_project_arn: str,
                 sls_write_role_arn: str,
                 status: str,
                 trail_name: str,
                 trail_region: str):
        """
        :param str event_rw: Indicates whether the event is a read or a write event.
        :param str id: The id of the ActionTrail Trail. It is the same as trail name.
        :param str oss_bucket_name: The name of the specified OSS bucket.
        :param str oss_key_prefix: The prefix of the specified OSS bucket name.
        :param str sls_project_arn: The unique ARN of the Log Service project.
        :param str sls_write_role_arn: The unique ARN of the Log Service role.
        :param str status: Filter the results by status of the ActionTrail Trail. Valid values: `Disable`, `Enable`, `Fresh`.
        :param str trail_name: The name of the ActionTrail Trail.
        :param str trail_region: The regions to which the trail is applied.
        """
        pulumi.set(__self__, "event_rw", event_rw)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_organization_trail", is_organization_trail)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_key_prefix", oss_key_prefix)
        pulumi.set(__self__, "oss_write_role_arn", oss_write_role_arn)
        pulumi.set(__self__, "sls_project_arn", sls_project_arn)
        pulumi.set(__self__, "sls_write_role_arn", sls_write_role_arn)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "trail_name", trail_name)
        pulumi.set(__self__, "trail_region", trail_region)

    @property
    @pulumi.getter(name="eventRw")
    def event_rw(self) -> str:
        """
        Indicates whether the event is a read or a write event.
        """
        return pulumi.get(self, "event_rw")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the ActionTrail Trail. It is the same as trail name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOrganizationTrail")
    def is_organization_trail(self) -> bool:
        return pulumi.get(self, "is_organization_trail")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the specified OSS bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossKeyPrefix")
    def oss_key_prefix(self) -> str:
        """
        The prefix of the specified OSS bucket name.
        """
        return pulumi.get(self, "oss_key_prefix")

    @property
    @pulumi.getter(name="ossWriteRoleArn")
    def oss_write_role_arn(self) -> str:
        return pulumi.get(self, "oss_write_role_arn")

    @property
    @pulumi.getter(name="slsProjectArn")
    def sls_project_arn(self) -> str:
        """
        The unique ARN of the Log Service project.
        """
        return pulumi.get(self, "sls_project_arn")

    @property
    @pulumi.getter(name="slsWriteRoleArn")
    def sls_write_role_arn(self) -> str:
        """
        The unique ARN of the Log Service role.
        """
        return pulumi.get(self, "sls_write_role_arn")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Filter the results by status of the ActionTrail Trail. Valid values: `Disable`, `Enable`, `Fresh`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trailName")
    def trail_name(self) -> str:
        """
        The name of the ActionTrail Trail.
        """
        return pulumi.get(self, "trail_name")

    @property
    @pulumi.getter(name="trailRegion")
    def trail_region(self) -> str:
        """
        The regions to which the trail is applied.
        """
        return pulumi.get(self, "trail_region")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDhcpOptionsSetsResult',
    'AwaitableGetDhcpOptionsSetsResult',
    'get_dhcp_options_sets',
    'get_dhcp_options_sets_output',
]

@pulumi.output_type
class GetDhcpOptionsSetsResult:
    """
    A collection of values returned by getDhcpOptionsSets.
    """
    def __init__(__self__, dhcp_options_set_name=None, domain_name=None, id=None, ids=None, name_regex=None, names=None, output_file=None, sets=None, status=None):
        if dhcp_options_set_name and not isinstance(dhcp_options_set_name, str):
            raise TypeError("Expected argument 'dhcp_options_set_name' to be a str")
        pulumi.set(__self__, "dhcp_options_set_name", dhcp_options_set_name)
        if domain_name and not isinstance(domain_name, str):
            raise TypeError("Expected argument 'domain_name' to be a str")
        pulumi.set(__self__, "domain_name", domain_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if sets and not isinstance(sets, list):
            raise TypeError("Expected argument 'sets' to be a list")
        pulumi.set(__self__, "sets", sets)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dhcpOptionsSetName")
    def dhcp_options_set_name(self) -> Optional[str]:
        return pulumi.get(self, "dhcp_options_set_name")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[str]:
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def sets(self) -> Sequence['outputs.GetDhcpOptionsSetsSetResult']:
        return pulumi.get(self, "sets")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetDhcpOptionsSetsResult(GetDhcpOptionsSetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDhcpOptionsSetsResult(
            dhcp_options_set_name=self.dhcp_options_set_name,
            domain_name=self.domain_name,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            sets=self.sets,
            status=self.status)


def get_dhcp_options_sets(dhcp_options_set_name: Optional[str] = None,
                          domain_name: Optional[str] = None,
                          ids: Optional[Sequence[str]] = None,
                          name_regex: Optional[str] = None,
                          output_file: Optional[str] = None,
                          status: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDhcpOptionsSetsResult:
    """
    This data source provides the Vpc Dhcp Options Sets of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.134.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"])
    pulumi.export("vpcDhcpOptionsSetId1", ids.sets[0].id)
    name_regex = alicloud.vpc.get_dhcp_options_sets(name_regex="^my-DhcpOptionsSet")
    pulumi.export("vpcDhcpOptionsSetId2", name_regex.sets[0].id)
    dhcp_options_set_name = alicloud.vpc.get_dhcp_options_sets(dhcp_options_set_name="my-DhcpOptionsSet")
    pulumi.export("vpcDhcpOptionsSetId3", dhcp_options_set_name.sets[0].id)
    domain_name = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"],
        domain_name="example.com")
    pulumi.export("vpcDhcpOptionsSetId4", domain_name.sets[0].id)
    status = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"],
        status="Available")
    pulumi.export("vpcDhcpOptionsSetId5", status.sets[0].id)
    ```


    :param str dhcp_options_set_name: The name of the DHCP options set.The name must be 2 to 128 characters in length and can contain letters, Chinese characters, digits, underscores (_), and hyphens (-). It must start with a letter or a Chinese character.
    :param str domain_name: The root domain, for example, example.com. After a DHCP options set is associated with a Virtual Private Cloud (VPC) network, the root domain in the DHCP options set is automatically synchronized to the ECS instances in the VPC network.
    :param Sequence[str] ids: A list of Dhcp Options Set IDs.
    :param str name_regex: A regex string to filter results by Dhcp Options Set name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the DHCP options set. Valid values: `Available`, `InUse` or `Pending`. `Available`: The DHCP options set is available for use. `InUse`: The DHCP options set is in use. `Pending`: The DHCP options set is being configured.
    """
    __args__ = dict()
    __args__['dhcpOptionsSetName'] = dhcp_options_set_name
    __args__['domainName'] = domain_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getDhcpOptionsSets:getDhcpOptionsSets', __args__, opts=opts, typ=GetDhcpOptionsSetsResult).value

    return AwaitableGetDhcpOptionsSetsResult(
        dhcp_options_set_name=pulumi.get(__ret__, 'dhcp_options_set_name'),
        domain_name=pulumi.get(__ret__, 'domain_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        sets=pulumi.get(__ret__, 'sets'),
        status=pulumi.get(__ret__, 'status'))
def get_dhcp_options_sets_output(dhcp_options_set_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 domain_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                 output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                 status: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDhcpOptionsSetsResult]:
    """
    This data source provides the Vpc Dhcp Options Sets of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.134.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"])
    pulumi.export("vpcDhcpOptionsSetId1", ids.sets[0].id)
    name_regex = alicloud.vpc.get_dhcp_options_sets(name_regex="^my-DhcpOptionsSet")
    pulumi.export("vpcDhcpOptionsSetId2", name_regex.sets[0].id)
    dhcp_options_set_name = alicloud.vpc.get_dhcp_options_sets(dhcp_options_set_name="my-DhcpOptionsSet")
    pulumi.export("vpcDhcpOptionsSetId3", dhcp_options_set_name.sets[0].id)
    domain_name = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"],
        domain_name="example.com")
    pulumi.export("vpcDhcpOptionsSetId4", domain_name.sets[0].id)
    status = alicloud.vpc.get_dhcp_options_sets(ids=["example_value"],
        status="Available")
    pulumi.export("vpcDhcpOptionsSetId5", status.sets[0].id)
    ```


    :param str dhcp_options_set_name: The name of the DHCP options set.The name must be 2 to 128 characters in length and can contain letters, Chinese characters, digits, underscores (_), and hyphens (-). It must start with a letter or a Chinese character.
    :param str domain_name: The root domain, for example, example.com. After a DHCP options set is associated with a Virtual Private Cloud (VPC) network, the root domain in the DHCP options set is automatically synchronized to the ECS instances in the VPC network.
    :param Sequence[str] ids: A list of Dhcp Options Set IDs.
    :param str name_regex: A regex string to filter results by Dhcp Options Set name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the DHCP options set. Valid values: `Available`, `InUse` or `Pending`. `Available`: The DHCP options set is available for use. `InUse`: The DHCP options set is in use. `Pending`: The DHCP options set is being configured.
    """
    __args__ = dict()
    __args__['dhcpOptionsSetName'] = dhcp_options_set_name
    __args__['domainName'] = domain_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getDhcpOptionsSets:getDhcpOptionsSets', __args__, opts=opts, typ=GetDhcpOptionsSetsResult)
    return __ret__.apply(lambda __response__: GetDhcpOptionsSetsResult(
        dhcp_options_set_name=pulumi.get(__response__, 'dhcp_options_set_name'),
        domain_name=pulumi.get(__response__, 'domain_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        sets=pulumi.get(__response__, 'sets'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterMulticastDomainSourcesResult',
    'AwaitableGetTransitRouterMulticastDomainSourcesResult',
    'get_transit_router_multicast_domain_sources',
    'get_transit_router_multicast_domain_sources_output',
]

@pulumi.output_type
class GetTransitRouterMulticastDomainSourcesResult:
    """
    A collection of values returned by getTransitRouterMulticastDomainSources.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, sources=None, transit_router_multicast_domain_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if sources and not isinstance(sources, list):
            raise TypeError("Expected argument 'sources' to be a list")
        pulumi.set(__self__, "sources", sources)
        if transit_router_multicast_domain_id and not isinstance(transit_router_multicast_domain_id, str):
            raise TypeError("Expected argument 'transit_router_multicast_domain_id' to be a str")
        pulumi.set(__self__, "transit_router_multicast_domain_id", transit_router_multicast_domain_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def sources(self) -> Sequence['outputs.GetTransitRouterMulticastDomainSourcesSourceResult']:
        """
        A list of Transit Router Multicast Domain Source Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter(name="transitRouterMulticastDomainId")
    def transit_router_multicast_domain_id(self) -> str:
        """
        The ID of the multicast domain to which the multicast source belongs.
        """
        return pulumi.get(self, "transit_router_multicast_domain_id")


class AwaitableGetTransitRouterMulticastDomainSourcesResult(GetTransitRouterMulticastDomainSourcesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterMulticastDomainSourcesResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            sources=self.sources,
            transit_router_multicast_domain_id=self.transit_router_multicast_domain_id)


def get_transit_router_multicast_domain_sources(ids: Optional[Sequence[str]] = None,
                                                output_file: Optional[str] = None,
                                                transit_router_multicast_domain_id: Optional[str] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterMulticastDomainSourcesResult:
    """
    This data source provides Cen Transit Router Multicast Domain Source available to the user.[What is Transit Router Multicast Domain Source](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-registertransitroutermulticastgroupsources)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_router_multicast_domain_sources(transit_router_multicast_domain_id="tr-mcast-domain-xxxxxx")
    pulumi.export("alicloudCenTransitRouterMulticastDomainSourceExampleId", default.sources[0].id)
    ```


    :param Sequence[str] ids: A list of the multicast domain IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str transit_router_multicast_domain_id: The ID of the multicast domain to which the multicast source belongs.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouterMulticastDomainSources:getTransitRouterMulticastDomainSources', __args__, opts=opts, typ=GetTransitRouterMulticastDomainSourcesResult).value

    return AwaitableGetTransitRouterMulticastDomainSourcesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        sources=pulumi.get(__ret__, 'sources'),
        transit_router_multicast_domain_id=pulumi.get(__ret__, 'transit_router_multicast_domain_id'))
def get_transit_router_multicast_domain_sources_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                       transit_router_multicast_domain_id: Optional[pulumi.Input[str]] = None,
                                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRouterMulticastDomainSourcesResult]:
    """
    This data source provides Cen Transit Router Multicast Domain Source available to the user.[What is Transit Router Multicast Domain Source](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-registertransitroutermulticastgroupsources)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_router_multicast_domain_sources(transit_router_multicast_domain_id="tr-mcast-domain-xxxxxx")
    pulumi.export("alicloudCenTransitRouterMulticastDomainSourceExampleId", default.sources[0].id)
    ```


    :param Sequence[str] ids: A list of the multicast domain IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str transit_router_multicast_domain_id: The ID of the multicast domain to which the multicast source belongs.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getTransitRouterMulticastDomainSources:getTransitRouterMulticastDomainSources', __args__, opts=opts, typ=GetTransitRouterMulticastDomainSourcesResult)
    return __ret__.apply(lambda __response__: GetTransitRouterMulticastDomainSourcesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        sources=pulumi.get(__response__, 'sources'),
        transit_router_multicast_domain_id=pulumi.get(__response__, 'transit_router_multicast_domain_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterMulticastDomainPeerMembersResult',
    'AwaitableGetTransitRouterMulticastDomainPeerMembersResult',
    'get_transit_router_multicast_domain_peer_members',
    'get_transit_router_multicast_domain_peer_members_output',
]

@pulumi.output_type
class GetTransitRouterMulticastDomainPeerMembersResult:
    """
    A collection of values returned by getTransitRouterMulticastDomainPeerMembers.
    """
    def __init__(__self__, id=None, ids=None, members=None, output_file=None, peer_transit_router_multicast_domains=None, resource_id=None, resource_type=None, transit_router_attachment_id=None, transit_router_multicast_domain_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if peer_transit_router_multicast_domains and not isinstance(peer_transit_router_multicast_domains, list):
            raise TypeError("Expected argument 'peer_transit_router_multicast_domains' to be a list")
        pulumi.set(__self__, "peer_transit_router_multicast_domains", peer_transit_router_multicast_domains)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if transit_router_attachment_id and not isinstance(transit_router_attachment_id, str):
            raise TypeError("Expected argument 'transit_router_attachment_id' to be a str")
        pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_multicast_domain_id and not isinstance(transit_router_multicast_domain_id, str):
            raise TypeError("Expected argument 'transit_router_multicast_domain_id' to be a str")
        pulumi.set(__self__, "transit_router_multicast_domain_id", transit_router_multicast_domain_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def members(self) -> Sequence['outputs.GetTransitRouterMulticastDomainPeerMembersMemberResult']:
        """
        A list of Transit Router Multicast Domain Peer Member Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="peerTransitRouterMulticastDomains")
    def peer_transit_router_multicast_domains(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "peer_transit_router_multicast_domains")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[str]:
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[str]:
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterMulticastDomainId")
    def transit_router_multicast_domain_id(self) -> str:
        """
        The ID of the multicast domain to which the multicast member belongs.
        """
        return pulumi.get(self, "transit_router_multicast_domain_id")


class AwaitableGetTransitRouterMulticastDomainPeerMembersResult(GetTransitRouterMulticastDomainPeerMembersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterMulticastDomainPeerMembersResult(
            id=self.id,
            ids=self.ids,
            members=self.members,
            output_file=self.output_file,
            peer_transit_router_multicast_domains=self.peer_transit_router_multicast_domains,
            resource_id=self.resource_id,
            resource_type=self.resource_type,
            transit_router_attachment_id=self.transit_router_attachment_id,
            transit_router_multicast_domain_id=self.transit_router_multicast_domain_id)


def get_transit_router_multicast_domain_peer_members(ids: Optional[Sequence[str]] = None,
                                                     output_file: Optional[str] = None,
                                                     peer_transit_router_multicast_domains: Optional[Sequence[str]] = None,
                                                     resource_id: Optional[str] = None,
                                                     resource_type: Optional[str] = None,
                                                     transit_router_attachment_id: Optional[str] = None,
                                                     transit_router_multicast_domain_id: Optional[str] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterMulticastDomainPeerMembersResult:
    """
    This data source provides Cen Transit Router Multicast Domain Peer Member available to the user. [What is Transit Router Multicast Domain Peer Member](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-registertransitroutermulticastgroupmembers)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_router_multicast_domain_peer_members(transit_router_multicast_domain_id="tr-mcast-domain-2d9oq455uk533zfrxx")
    pulumi.export("alicloudCenTransitRouterMulticastDomainPeerMemberExampleId", default.members[0].id)
    ```


    :param Sequence[str] ids: A list of Cen Transit Router Multicast Domain Peer Member IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Sequence[str] peer_transit_router_multicast_domains: The IDs of the inter-region multicast domains.
    :param str resource_id: The ID of the resource associated with the multicast resource.
    :param str resource_type: The type of the multicast resource. Valid values:
           * VPC: queries multicast resources by VPC.
           * TR: queries multicast resources that are also deployed in a different region.
    :param str transit_router_attachment_id: The ID of the network instance connection.
    :param str transit_router_multicast_domain_id: The ID of the multicast domain to which the multicast member belongs.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['peerTransitRouterMulticastDomains'] = peer_transit_router_multicast_domains
    __args__['resourceId'] = resource_id
    __args__['resourceType'] = resource_type
    __args__['transitRouterAttachmentId'] = transit_router_attachment_id
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouterMulticastDomainPeerMembers:getTransitRouterMulticastDomainPeerMembers', __args__, opts=opts, typ=GetTransitRouterMulticastDomainPeerMembersResult).value

    return AwaitableGetTransitRouterMulticastDomainPeerMembersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        members=pulumi.get(__ret__, 'members'),
        output_file=pulumi.get(__ret__, 'output_file'),
        peer_transit_router_multicast_domains=pulumi.get(__ret__, 'peer_transit_router_multicast_domains'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        transit_router_attachment_id=pulumi.get(__ret__, 'transit_router_attachment_id'),
        transit_router_multicast_domain_id=pulumi.get(__ret__, 'transit_router_multicast_domain_id'))
def get_transit_router_multicast_domain_peer_members_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                            peer_transit_router_multicast_domains: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                            resource_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                            resource_type: Optional[pulumi.Input[Optional[str]]] = None,
                                                            transit_router_attachment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                            transit_router_multicast_domain_id: Optional[pulumi.Input[str]] = None,
                                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRouterMulticastDomainPeerMembersResult]:
    """
    This data source provides Cen Transit Router Multicast Domain Peer Member available to the user. [What is Transit Router Multicast Domain Peer Member](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-registertransitroutermulticastgroupmembers)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_router_multicast_domain_peer_members(transit_router_multicast_domain_id="tr-mcast-domain-2d9oq455uk533zfrxx")
    pulumi.export("alicloudCenTransitRouterMulticastDomainPeerMemberExampleId", default.members[0].id)
    ```


    :param Sequence[str] ids: A list of Cen Transit Router Multicast Domain Peer Member IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Sequence[str] peer_transit_router_multicast_domains: The IDs of the inter-region multicast domains.
    :param str resource_id: The ID of the resource associated with the multicast resource.
    :param str resource_type: The type of the multicast resource. Valid values:
           * VPC: queries multicast resources by VPC.
           * TR: queries multicast resources that are also deployed in a different region.
    :param str transit_router_attachment_id: The ID of the network instance connection.
    :param str transit_router_multicast_domain_id: The ID of the multicast domain to which the multicast member belongs.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['peerTransitRouterMulticastDomains'] = peer_transit_router_multicast_domains
    __args__['resourceId'] = resource_id
    __args__['resourceType'] = resource_type
    __args__['transitRouterAttachmentId'] = transit_router_attachment_id
    __args__['transitRouterMulticastDomainId'] = transit_router_multicast_domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getTransitRouterMulticastDomainPeerMembers:getTransitRouterMulticastDomainPeerMembers', __args__, opts=opts, typ=GetTransitRouterMulticastDomainPeerMembersResult)
    return __ret__.apply(lambda __response__: GetTransitRouterMulticastDomainPeerMembersResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        members=pulumi.get(__response__, 'members'),
        output_file=pulumi.get(__response__, 'output_file'),
        peer_transit_router_multicast_domains=pulumi.get(__response__, 'peer_transit_router_multicast_domains'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        transit_router_attachment_id=pulumi.get(__response__, 'transit_router_attachment_id'),
        transit_router_multicast_domain_id=pulumi.get(__response__, 'transit_router_multicast_domain_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ExternalDataServiceArgs', 'ExternalDataService']

@pulumi.input_type
class ExternalDataServiceArgs:
    def __init__(__self__, *,
                 db_instance_id: pulumi.Input[str],
                 service_name: pulumi.Input[str],
                 service_spec: pulumi.Input[str],
                 service_description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ExternalDataService resource.
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] service_name: Service Name
        :param pulumi.Input[str] service_spec: Service Specifications
        :param pulumi.Input[str] service_description: Service Description
        """
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "service_spec", service_spec)
        if service_description is not None:
            pulumi.set(__self__, "service_description", service_description)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[str]:
        """
        Service Name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="serviceSpec")
    def service_spec(self) -> pulumi.Input[str]:
        """
        Service Specifications
        """
        return pulumi.get(self, "service_spec")

    @service_spec.setter
    def service_spec(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_spec", value)

    @property
    @pulumi.getter(name="serviceDescription")
    def service_description(self) -> Optional[pulumi.Input[str]]:
        """
        Service Description
        """
        return pulumi.get(self, "service_description")

    @service_description.setter
    def service_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_description", value)


@pulumi.input_type
class _ExternalDataServiceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 service_description: Optional[pulumi.Input[str]] = None,
                 service_id: Optional[pulumi.Input[int]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 service_spec: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ExternalDataService resources.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] service_description: Service Description
        :param pulumi.Input[int] service_id: Service ID
        :param pulumi.Input[str] service_name: Service Name
        :param pulumi.Input[str] service_spec: Service Specifications
        :param pulumi.Input[str] status: The status of the resource
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if service_description is not None:
            pulumi.set(__self__, "service_description", service_description)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if service_spec is not None:
            pulumi.set(__self__, "service_spec", service_spec)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="serviceDescription")
    def service_description(self) -> Optional[pulumi.Input[str]]:
        """
        Service Description
        """
        return pulumi.get(self, "service_description")

    @service_description.setter
    def service_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_description", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[int]]:
        """
        Service ID
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        Service Name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="serviceSpec")
    def service_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Service Specifications
        """
        return pulumi.get(self, "service_spec")

    @service_spec.setter
    def service_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ExternalDataService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 service_description: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 service_spec: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GPDB External Data Service resource.

        External Data Services.

        For information about GPDB External Data Service and how to use it, see [What is External Data Service](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultrple4a = alicloud.vpc.Network("defaultrple4a", cidr_block="192.168.0.0/16")
        defaultn_yw_skl = alicloud.vpc.Switch("defaultnYWSkl",
            vpc_id=defaultrple4a.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_z7_d_pg_b = alicloud.gpdb.Instance("defaultZ7DPgB",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultn_yw_skl.id,
            storage_size=50,
            master_cu=4,
            vpc_id=defaultrple4a.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default_external_data_service = alicloud.gpdb.ExternalDataService("default",
            service_name="example6",
            db_instance_id=default_z7_d_pg_b.id,
            service_description="example",
            service_spec="8")
        ```

        ## Import

        GPDB External Data Service can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/externalDataService:ExternalDataService example <db_instance_id>:<service_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] service_description: Service Description
        :param pulumi.Input[str] service_name: Service Name
        :param pulumi.Input[str] service_spec: Service Specifications
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExternalDataServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GPDB External Data Service resource.

        External Data Services.

        For information about GPDB External Data Service and how to use it, see [What is External Data Service](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        defaultrple4a = alicloud.vpc.Network("defaultrple4a", cidr_block="192.168.0.0/16")
        defaultn_yw_skl = alicloud.vpc.Switch("defaultnYWSkl",
            vpc_id=defaultrple4a.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_z7_d_pg_b = alicloud.gpdb.Instance("defaultZ7DPgB",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaultn_yw_skl.id,
            storage_size=50,
            master_cu=4,
            vpc_id=defaultrple4a.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default_external_data_service = alicloud.gpdb.ExternalDataService("default",
            service_name="example6",
            db_instance_id=default_z7_d_pg_b.id,
            service_description="example",
            service_spec="8")
        ```

        ## Import

        GPDB External Data Service can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/externalDataService:ExternalDataService example <db_instance_id>:<service_id>
        ```

        :param str resource_name: The name of the resource.
        :param ExternalDataServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExternalDataServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 service_description: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 service_spec: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExternalDataServiceArgs.__new__(ExternalDataServiceArgs)

            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            __props__.__dict__["service_description"] = service_description
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if service_spec is None and not opts.urn:
                raise TypeError("Missing required property 'service_spec'")
            __props__.__dict__["service_spec"] = service_spec
            __props__.__dict__["create_time"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["status"] = None
        super(ExternalDataService, __self__).__init__(
            'alicloud:gpdb/externalDataService:ExternalDataService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            db_instance_id: Optional[pulumi.Input[str]] = None,
            service_description: Optional[pulumi.Input[str]] = None,
            service_id: Optional[pulumi.Input[int]] = None,
            service_name: Optional[pulumi.Input[str]] = None,
            service_spec: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ExternalDataService':
        """
        Get an existing ExternalDataService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] service_description: Service Description
        :param pulumi.Input[int] service_id: Service ID
        :param pulumi.Input[str] service_name: Service Name
        :param pulumi.Input[str] service_spec: Service Specifications
        :param pulumi.Input[str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExternalDataServiceState.__new__(_ExternalDataServiceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["service_description"] = service_description
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["service_spec"] = service_spec
        __props__.__dict__["status"] = status
        return ExternalDataService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="serviceDescription")
    def service_description(self) -> pulumi.Output[Optional[str]]:
        """
        Service Description
        """
        return pulumi.get(self, "service_description")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[int]:
        """
        Service ID
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[str]:
        """
        Service Name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="serviceSpec")
    def service_spec(self) -> pulumi.Output[str]:
        """
        Service Specifications
        """
        return pulumi.get(self, "service_spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBindingsBindingResult',
    'GetExchangesExchangeResult',
    'GetInstancesInstanceResult',
    'GetQueuesQueueResult',
    'GetStaticAccountsAccountResult',
    'GetVirtualHostsHostResult',
]

@pulumi.output_type
class GetBindingsBindingResult(dict):
    def __init__(__self__, *,
                 argument: str,
                 binding_key: str,
                 binding_type: str,
                 destination_name: str,
                 id: str,
                 instance_id: str,
                 source_exchange: str,
                 virtual_host_name: str):
        """
        :param str argument: X-match Attributes. Valid Values: All: Default Value, All the Message Header of Key-Value Pairs Stored in the Must Match. Any: at Least One Pair of the Message Header of Key-Value Pairs Stored in the Must Match. This Parameter Applies Only to Headers Exchange Other Types of Exchange Is Invalid. Other Types of Exchange Here Can Either Be an Arbitrary Value.
        :param str binding_key: The Binding Key. The Source of the Binding Exchange Non-Topic Type: Can Only Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). Length from 1 to 255 Characters. The Source of the Binding Exchange Topic Type: Can Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). If You Include the Hash (.
        :param str binding_type: The Target Binding Types.
        :param str destination_name: The Target Queue Or Exchange of the Name.
        :param str id: The ID of the Binding. The value formats as `<instance_id>:<virtual_host_name>:<source_exchange>:<destination_name>`.
        :param str instance_id: Instance Id.
        :param str source_exchange: The Source Exchange Name.
        :param str virtual_host_name: Virtualhost Name.
        """
        pulumi.set(__self__, "argument", argument)
        pulumi.set(__self__, "binding_key", binding_key)
        pulumi.set(__self__, "binding_type", binding_type)
        pulumi.set(__self__, "destination_name", destination_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "source_exchange", source_exchange)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def argument(self) -> str:
        """
        X-match Attributes. Valid Values: All: Default Value, All the Message Header of Key-Value Pairs Stored in the Must Match. Any: at Least One Pair of the Message Header of Key-Value Pairs Stored in the Must Match. This Parameter Applies Only to Headers Exchange Other Types of Exchange Is Invalid. Other Types of Exchange Here Can Either Be an Arbitrary Value.
        """
        return pulumi.get(self, "argument")

    @property
    @pulumi.getter(name="bindingKey")
    def binding_key(self) -> str:
        """
        The Binding Key. The Source of the Binding Exchange Non-Topic Type: Can Only Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). Length from 1 to 255 Characters. The Source of the Binding Exchange Topic Type: Can Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). If You Include the Hash (.
        """
        return pulumi.get(self, "binding_key")

    @property
    @pulumi.getter(name="bindingType")
    def binding_type(self) -> str:
        """
        The Target Binding Types.
        """
        return pulumi.get(self, "binding_type")

    @property
    @pulumi.getter(name="destinationName")
    def destination_name(self) -> str:
        """
        The Target Queue Or Exchange of the Name.
        """
        return pulumi.get(self, "destination_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Binding. The value formats as `<instance_id>:<virtual_host_name>:<source_exchange>:<destination_name>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        Instance Id.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="sourceExchange")
    def source_exchange(self) -> str:
        """
        The Source Exchange Name.
        """
        return pulumi.get(self, "source_exchange")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> str:
        """
        Virtualhost Name.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetExchangesExchangeResult(dict):
    def __init__(__self__, *,
                 attributes: Mapping[str, str],
                 auto_delete_state: bool,
                 create_time: str,
                 exchange_name: str,
                 exchange_type: str,
                 id: str,
                 instance_id: str,
                 virtual_host_name: str):
        """
        :param Mapping[str, str] attributes: The attributes.
        :param bool auto_delete_state: Indicates whether the Auto Delete attribute is configured.
        :param str create_time: The creation time.
        :param str exchange_name: The name of the exchange.
        :param str exchange_type: The type of the exchange.
        :param str id: The ID of the Exchange. Its value is same as Queue Name.
        :param str instance_id: The ID of the instance.
        :param str virtual_host_name: The name of virtual host where an exchange resides.
        """
        pulumi.set(__self__, "attributes", attributes)
        pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "exchange_name", exchange_name)
        pulumi.set(__self__, "exchange_type", exchange_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def attributes(self) -> Mapping[str, str]:
        """
        The attributes.
        """
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> bool:
        """
        Indicates whether the Auto Delete attribute is configured.
        """
        return pulumi.get(self, "auto_delete_state")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="exchangeName")
    def exchange_name(self) -> str:
        """
        The name of the exchange.
        """
        return pulumi.get(self, "exchange_name")

    @property
    @pulumi.getter(name="exchangeType")
    def exchange_type(self) -> str:
        """
        The type of the exchange.
        """
        return pulumi.get(self, "exchange_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Exchange. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> str:
        """
        The name of virtual host where an exchange resides.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 expire_time: str,
                 id: str,
                 instance_id: str,
                 instance_name: str,
                 instance_type: str,
                 payment_type: str,
                 private_end_point: str,
                 public_endpoint: str,
                 renewal_duration: int,
                 renewal_duration_unit: str,
                 renewal_status: str,
                 status: str,
                 support_eip: bool):
        """
        :param str create_time: OrderCreateTime.
        :param str expire_time: ExpireTime.
        :param str id: The ID of the Instance.
        :param str instance_id: THe instance Id.
        :param str instance_name: THe instance name.
        :param str instance_type: The instance type.
        :param str payment_type: The Pay-as-You-Type Values Include: the Subscription of a Pre-Paid.
        :param str private_end_point: The private endPoint.
        :param str public_endpoint: The public dndpoint.
        :param int renewal_duration: Renewal duration.
        :param str renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param str renewal_status: Renew status.
        :param str status: The status of the resource.
        :param bool support_eip: Whether to support eip.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "private_end_point", private_end_point)
        pulumi.set(__self__, "public_endpoint", public_endpoint)
        pulumi.set(__self__, "renewal_duration", renewal_duration)
        pulumi.set(__self__, "renewal_duration_unit", renewal_duration_unit)
        pulumi.set(__self__, "renewal_status", renewal_status)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "support_eip", support_eip)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        OrderCreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> str:
        """
        ExpireTime.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        THe instance Id.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> str:
        """
        THe instance name.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        """
        The instance type.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The Pay-as-You-Type Values Include: the Subscription of a Pre-Paid.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="privateEndPoint")
    def private_end_point(self) -> str:
        """
        The private endPoint.
        """
        return pulumi.get(self, "private_end_point")

    @property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> str:
        """
        The public dndpoint.
        """
        return pulumi.get(self, "public_endpoint")

    @property
    @pulumi.getter(name="renewalDuration")
    def renewal_duration(self) -> int:
        """
        Renewal duration.
        """
        return pulumi.get(self, "renewal_duration")

    @property
    @pulumi.getter(name="renewalDurationUnit")
    def renewal_duration_unit(self) -> str:
        """
        Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        """
        return pulumi.get(self, "renewal_duration_unit")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> str:
        """
        Renew status.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportEip")
    def support_eip(self) -> bool:
        """
        Whether to support eip.
        """
        return pulumi.get(self, "support_eip")


@pulumi.output_type
class GetQueuesQueueResult(dict):
    def __init__(__self__, *,
                 attributes: Mapping[str, str],
                 auto_delete_state: bool,
                 create_time: str,
                 exclusive_state: bool,
                 id: str,
                 instance_id: str,
                 last_consume_time: str,
                 queue_name: str,
                 virtual_host_name: str):
        """
        :param Mapping[str, str] attributes: The attributes for the Queue.
        :param bool auto_delete_state: Specifies whether the Auto Delete attribute is configured.
        :param str create_time: CreateTime.
        :param bool exclusive_state: Specifies whether the queue is an exclusive queue.
        :param str id: The ID of the Queue. Its value is same as Queue Name.
        :param str instance_id: The ID of the instance.
        :param str last_consume_time: The last consume time.
        :param str queue_name: The queue name.
        :param str virtual_host_name: The name of the virtual host.
        """
        pulumi.set(__self__, "attributes", attributes)
        pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "exclusive_state", exclusive_state)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "last_consume_time", last_consume_time)
        pulumi.set(__self__, "queue_name", queue_name)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def attributes(self) -> Mapping[str, str]:
        """
        The attributes for the Queue.
        """
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> bool:
        """
        Specifies whether the Auto Delete attribute is configured.
        """
        return pulumi.get(self, "auto_delete_state")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        CreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="exclusiveState")
    def exclusive_state(self) -> bool:
        """
        Specifies whether the queue is an exclusive queue.
        """
        return pulumi.get(self, "exclusive_state")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Queue. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="lastConsumeTime")
    def last_consume_time(self) -> str:
        """
        The last consume time.
        """
        return pulumi.get(self, "last_consume_time")

    @property
    @pulumi.getter(name="queueName")
    def queue_name(self) -> str:
        """
        The queue name.
        """
        return pulumi.get(self, "queue_name")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> str:
        """
        The name of the virtual host.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetStaticAccountsAccountResult(dict):
    def __init__(__self__, *,
                 access_key: str,
                 create_time: str,
                 id: str,
                 instance_id: str,
                 master_uid: str,
                 password: str,
                 user_name: str):
        """
        :param str access_key: Access key.
        :param str create_time: Create time stamp. Unix timestamp, to millisecond level.
        :param str id: The `key` of the resource supplied above.The value is formulated as `<instance_id>:<access_key>`.
        :param str instance_id: InstanceId
        :param str master_uid: The ID of the user's primary account.
        :param str password: Static password.
        :param str user_name: Static username.
        """
        pulumi.set(__self__, "access_key", access_key)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "master_uid", master_uid)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> str:
        """
        Access key.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Create time stamp. Unix timestamp, to millisecond level.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The `key` of the resource supplied above.The value is formulated as `<instance_id>:<access_key>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        InstanceId
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="masterUid")
    def master_uid(self) -> str:
        """
        The ID of the user's primary account.
        """
        return pulumi.get(self, "master_uid")

    @property
    @pulumi.getter
    def password(self) -> str:
        """
        Static password.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> str:
        """
        Static username.
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetVirtualHostsHostResult(dict):
    def __init__(__self__, *,
                 id: str,
                 instance_id: str,
                 virtual_host_name: str):
        """
        :param str id: The ID of the Virtual Host.
        :param str instance_id: InstanceId.
        :param str virtual_host_name: VirtualHostName.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Virtual Host.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        InstanceId.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> str:
        """
        VirtualHostName.
        """
        return pulumi.get(self, "virtual_host_name")


